# Datatypes

I've been creating the same types of classes over and over and I finally want to collect these classes into a central location that I can pull into multiple projects.


## Installation

Install latest stable with the following command.

    $ pip install datatypes
    
Or install the latest and greatest from source:

    $ pip install -U "git+https://github.com/jaymon/datatypes#egg=datatypes"